Index: trunk/MagicSoft/Mars/macros/calibration.C
===================================================================
--- trunk/MagicSoft/Mars/macros/calibration.C	(revision 3309)
+++ trunk/MagicSoft/Mars/macros/calibration.C	(revision 3310)
@@ -354,7 +354,11 @@
 
     //
-    // print the most important results of all pixels
-    //
+    // print the most important results of all pixels to a file
+    //
+    MLog gauglog;
+    gauglog.SetOutputFile(Form("%s%s",calcam.GetName(),".txt"),1);
+    calcam.SetLogStream(&gauglog);
     calcam.Print();
+    calcam.SetLogStream(&gLog);
 
     //
